# [NRSurrogate catalog](https://cjhaster.github.io/NRSurrogateCatalog)
    
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8115310.svg)](https://doi.org/10.5281/zenodo.8115310)

GW event posteriors obtained using numerical relativity surrogate models.

This package contains the code to use the NRSurrogate Catalog API to 
download and plot the posteriors for GW events. 
